import { PartiallyConstructible } from '../../utils';
import { DocumentScannerOutputSettings } from '../document/DocumentScannerOutputSettings';
import { DocumentScannerScreens } from '../document/DocumentScannerScreens';
import { DocumentScannerTextLocalization } from '../document/DocumentScannerTextLocalization';
import { Palette } from '../common/Common';
/**
Configuration of the general appearance.
*/
export class DocumentFlowAppearanceConfiguration extends PartiallyConstructible {
  /**
    Determines the visual mode used for the status bar icons.
    Default is LIGHT
    */
  statusBarMode = 'LIGHT';
  /**
    Determines the visual mode used for the navigation bar icons. Android only.
    Default is LIGHT
    */
  navigationBarMode = 'LIGHT';
  /**
    The background color of the top bar. Only applicable when the visual mode is specified as 'SOLID', otherwise ignored.
    Default is "?sbColorPrimary"
    */
  topBarBackgroundColor = '?sbColorPrimary';
  /**
    The background color of the bottom bar.
    Default is "?sbColorPrimary"
    */
  bottomBarBackgroundColor = '?sbColorPrimary';
  /**
    Which mode to use when orientation should be locked to landscape or portrait.
    Default is NONE
    */
  orientationLockMode = 'NONE';

  /** @param source {@displayType `DeepPartial<DocumentFlowAppearanceConfiguration>`} */
  constructor(source = {}) {
    super();
    if (source.statusBarMode !== undefined) {
      this.statusBarMode = source.statusBarMode;
    }
    if (source.navigationBarMode !== undefined) {
      this.navigationBarMode = source.navigationBarMode;
    }
    if (source.topBarBackgroundColor !== undefined) {
      this.topBarBackgroundColor = source.topBarBackgroundColor;
    }
    if (source.bottomBarBackgroundColor !== undefined) {
      this.bottomBarBackgroundColor = source.bottomBarBackgroundColor;
    }
    if (source.orientationLockMode !== undefined) {
      this.orientationLockMode = source.orientationLockMode;
    }
  }
}

/**
Configuration of the document scanner screen.
*/
export class DocumentScanningFlow extends PartiallyConstructible {
  /**
    Version number of the configuration object.
    Default is "1.0"
    */
  version = '1.0';
  /**
    The configuration object should be applied for this screen.
    Default is "DocumentScanner"
    */
  screen = 'DocumentScanner';
  /**
    Define the screen's base color values from which other colors are derived.
    */
  palette = new Palette({
    sbColorPrimary: '#C8193C',
    sbColorPrimaryDisabled: '#F5F5F5',
    sbColorNegative: '#FF3737',
    sbColorPositive: '#4EFFB4',
    sbColorWarning: '#FFCE5C',
    sbColorSecondary: '#FFEDEE',
    sbColorSecondaryDisabled: '#F5F5F5',
    sbColorOnPrimary: '#FFFFFF',
    sbColorOnSecondary: '#C8193C',
    sbColorSurface: '#FFFFFF',
    sbColorOutline: '#EFEFEF',
    sbColorOnSurfaceVariant: '#707070',
    sbColorOnSurface: '#000000',
    sbColorSurfaceLow: '#00000026',
    sbColorSurfaceHigh: '#0000007A',
    sbColorModalOverlay: '#000000A3'
  });
  /**
    Configuration of all the strings for the document scanner screen.
    */
  localization = new DocumentScannerTextLocalization({});
  /**
    Configuration of the general appearance.
    */
  appearance = new DocumentFlowAppearanceConfiguration({});
  /**
    Configuration of the output settings.
    */
  outputSettings = new DocumentScannerOutputSettings({});
  /**
    Configuration of the document scanner sub-screens.
    */
  screens = new DocumentScannerScreens({});
  /**
    The UUID of the existing document to be edited.
    */
  documentUuid = null;
  /**
    Clean the existing pages from the scanning session.
    Default is true
    */
  cleanScanningSession = true;

  /** @param source {@displayType `DeepPartial<DocumentScanningFlow>`} */
  constructor(source = {}) {
    super();
    if (source.version !== undefined) {
      this.version = source.version;
    }
    if (source.screen !== undefined) {
      this.screen = source.screen;
    }
    if (source.palette !== undefined) {
      this.palette = new Palette(source.palette);
    }
    if (source.localization !== undefined) {
      this.localization = new DocumentScannerTextLocalization(source.localization);
    }
    if (source.appearance !== undefined) {
      this.appearance = new DocumentFlowAppearanceConfiguration(source.appearance);
    }
    if (source.outputSettings !== undefined) {
      this.outputSettings = new DocumentScannerOutputSettings(source.outputSettings);
    }
    if (source.screens !== undefined) {
      this.screens = new DocumentScannerScreens(source.screens);
    }
    if (source.documentUuid !== undefined) {
      this.documentUuid = source.documentUuid != null ? source.documentUuid : null;
    }
    if (source.cleanScanningSession !== undefined) {
      this.cleanScanningSession = source.cleanScanningSession;
    }
  }
}
//# sourceMappingURL=DocumentScanningFlow.js.map