import { AspectRatio } from '../common/Common';
import { CameraModule } from '../common/CameraConfiguration';
import { CameraPreviewMode } from '../common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils';
/**
Determines the prioritization of still image quality and capturing speed.

- `SPEED`:
   Captures a still image at the highest possible speed. The quality of the image may be degraded.
- `BALANCED`:
   Balances capturing speed and image quality equally. This is the default value.
- `QUALITY`:
   Captures a still image with the best possible quality in terms of noise, frozen motion and detail in low light. The speed of the capturing might be reduced.
*/
export type CapturePhotoQualityPrioritization = 'SPEED' | 'BALANCED' | 'QUALITY';
/**
Configuration of the camera behavior.
*/
export declare class DocumentScannerCameraConfiguration extends PartiallyConstructible {
    /**
      Determines which camera module to use on start-up.
      Default is BACK
      */
    cameraModule: CameraModule;
    /**
      The default zoom factor on start-up.
      Default is 1.0
      */
    defaultZoomFactor: number;
    /**
      Determines whether the flashlight is enabled or not on start-up.
      Default is false
      */
    flashEnabled: boolean;
    /**
      Determines whether locking the focus at the minimum possible distance is enabled or not (device-specific).
      Default is false
      */
    minFocusDistanceLock: boolean;
    /**
      Determines whether touch-to-focus is enabled or not. Android only.
      Default is false
      */
    touchToFocusEnabled: boolean;
    /**
      Determines whether pinch-to-zoom is enabled or not.
      Default is true
      */
    pinchToZoomEnabled: boolean;
    /**
      Determines which camera preview mode to use.
      Default is FILL_IN
      */
    cameraPreviewMode: CameraPreviewMode;
    /**
      Determines the prioritization of still image quality and capturing speed.
      Default is BALANCED
      */
    captureQualityPrioritization: CapturePhotoQualityPrioritization;
    /**
      The minimum pitch/skew angle of the document to be accepted. The value must be between 0.0 and 1.0.
      Default is 0.75
      */
    acceptedAngleScore: number;
    /**
      The minimum size of the document in relation to the screen preview to be accepted. The value must be between 0.0 and 1.0.
      Default is 0.75
      */
    acceptedSizeScore: number;
    /**
      Controls the auto snapping speed. The sensitivity must be between 0.0 and 1.0. A value of 1.0 triggers auto snapping immediately, while a value of 0.0 delays the auto snapping by 3 seconds. The default value is 0.66 (1 second).
      Default is 0.66
      */
    autoSnappingSensitivity: number;
    /**
      After a page has been snapped, the delay in milliseconds before auto snapping resumes for the next page.
      Default is 200
      */
    autoSnappingDelay: number;
    /**
      The minimum brightness value to accept a detected document.
      Default is 50
      */
    acceptedBrightnessThreshold: number;
    /**
      Determines if auto snapping is enabled or not.
      Default is true
      */
    autoSnappingEnabled: boolean;
    /**
      The required aspect ratios for the document to be accepted.
      */
    requiredAspectRatios: AspectRatio[];
    /**
      Determines whether a landscape document will be detected when the camera is in portrait mode (and vice versa) or not. This parameter will be ignored if required aspect ratios have been explicitly defined.
      Default is true
      */
    ignoreBadAspectRatio: boolean;
    /**
      When enabled the hardware volume up/down buttons can be used to capture an image if manual snapping is enabled. For iOS version 17.2 or later is required. On iPhones with camera control (iPhone 16 series) this also enables zooming and capturing with the camera control.
      Default is true
      */
    captureWithHardwareButtonsEnabled: boolean;
    /** @param source {@displayType `DeepPartial<DocumentScannerCameraConfiguration>`} */
    constructor(source?: DeepPartial<DocumentScannerCameraConfiguration>);
}
//# sourceMappingURL=DocumentScannerCameraConfiguration.d.ts.map